@@ -285,18 +285,18 @@ function registerBuiltins(devMode) {
   const electronAsarRoot = path.join(process.resourcesPath, 'electron.asar');
 
   const commonRoot = path.join(electronAsarRoot, 'common', 'api');
-  const commonBuiltins = [
-    'callbacks-registry',
-    'clipboard',
-    'crash-reporter',
-    'shell'
-  ];
+  const commonBuiltins = ['clipboard', 'shell'];
   for (const builtin of commonBuiltins) {
     cache.builtins[builtin] = path.join(commonRoot, `${builtin}.js`);
   }
 
   const rendererRoot = path.join(electronAsarRoot, 'renderer', 'api');
-  const rendererBuiltins = ['ipc-renderer', 'remote', 'screen'];
+  const rendererBuiltins = [
+    'crash-reporter',
+    'ipc-renderer',
+    'remote',
+    'screen'
+  ];
   for (const builtin of rendererBuiltins) {
     cache.builtins[builtin] = path.join(rendererRoot, `${builtin}.js`);
   }
