@@ -1010,7 +1010,8 @@ class HighlightIterator {
       if (
         next.offset === first.offset &&
         next.atEnd === first.atEnd &&
-        next.depth > first.depth
+        next.depth > first.depth &&
+        !next.isAtInjectionBoundary()
       ) {
         this.currentScopeIsCovered = true;
         return;
@@ -1217,6 +1218,10 @@ class LayerHighlightIterator {
     return this.openTags.slice();
   }
 
+  isAtInjectionBoundary() {
+    return this.containingNodeTypes.length === 1;
+  }
+
   // Private methods
 
   _moveUp(atLastChild) {
